Module types

Module types 

Structs

AgentsMdMetadata
ClientSystemInfo
Snapshot of coarse client machine characteristics captured when the socket connects.
LocalSkillMetadata
ModelConfig
ThreadModelOverride
ToolCallOutput
Usage

Enums

Arch
Normalized CPU architecture reported by a client during the handshake.
ClientMessage
MessageStatus
Os
Normalized operating system family reported by a client during the handshake.
Role
RuntimeMode
ServerMessage
SubagentEscalationResolution
ToolCallApproval
ToolExecutionTarget